@@ -1186,6 +1186,11 @@ class CausalTree:
     def save_pickle(self, filename):
         import pickle as pkl
 
+        if ".pkl" not in filename:
+            filename = filename + ".pkl"
+
+        check_dir(filename)
+
         with open(filename, "wb") as file:
             pkl.dump(self, file)
 
